@@ -7,7 +7,7 @@ use std::cmp::Ordering;
 
 #[derive(Eq, PartialEq)]
 /// Creates a custom Bytes32 type, a 4 byte wide vector.
-struct Bytes32<'a> {
+pub struct Bytes32<'a> {
    pub store: Vec<[&'a u8; 4]>, 
 }
 
